# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepBndLib module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepbndlib.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepBndLib
else:
    import _BRepBndLib

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepBndLib.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepBndLib.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepBndLib.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepBndLib.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepBndLib.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepBndLib.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepBndLib.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepBndLib.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepBndLib.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepBndLib.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepBndLib.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepBndLib.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepBndLib.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepBndLib.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepBndLib.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepBndLib.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepBndLib.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepBndLib:
_BRepBndLib.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepBndLib.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Bnd
import OCC.Core.TColgp
import OCC.Core.BVH

from enum import IntEnum
from OCC.Core.Exception import *



class brepbndlib(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Add(*args) -> "void":
        r"""
        Adds the shape s to the bounding box b. more precisely are successively added to b: - each face of s; the triangulation of the face is used if it exists, - then each edge of s which does not belong to a face, the polygon of the edge is used if it exists - and last each vertex of s which does not belong to an edge. after each elementary operation, the bounding box b is enlarged by the tolerance value of the relative sub-shape. when working with the triangulation of a face this value of enlargement is the sum of the triangulation deflection and the face tolerance. when working with the polygon of an edge this value of enlargement is the sum of the polygon deflection and the edge tolerance. warning - this algorithm is time consuming if triangulation has not been inserted inside the data structure of the shape s. - the resulting bounding box may be somewhat larger than the object.

        Parameters
        ----------
        S: TopoDS_Shape
        B: Bnd_Box
        useTriangulation: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _BRepBndLib.brepbndlib_Add(*args)

    @staticmethod
    def AddClose(*args) -> "void":
        r"""
        Adds the shape s to the bounding box b. this is a quick algorithm but only works if the shape s is composed of polygonal planar faces, as is the case if s is an approached polyhedral representation of an exact shape. pay particular attention to this because this condition is not checked and, if it not respected, an error may occur in the algorithm for which the bounding box is built. note that the resulting bounding box is not enlarged by the tolerance value of the sub-shapes as is the case with the add function. so the added part of the resulting bounding box is closer to the shape s.

        Parameters
        ----------
        S: TopoDS_Shape
        B: Bnd_Box

        Returns
        -------
        None

        """
        return _BRepBndLib.brepbndlib_AddClose(*args)

    @staticmethod
    def AddOBB(*args) -> "void":
        r"""
        Computes the oriented bounding box for the shape <thes>. two independent methods of computation are implemented: first method based on set of points (so, it demands the triangulated shape or shape with planar faces and linear edges). the second method is based on use of inertia axes and is called if use of the first method is impossible. if theistriangulationused == false then the triangulation will be ignored at all. if theisshapetoleranceused == true then resulting box will be extended on the tolerance of the shape. theisoptimal flag defines whether to look for the more tight obb for the cost of performance or not.

        Parameters
        ----------
        theS: TopoDS_Shape
        theOBB: Bnd_OBB
        theIsTriangulationUsed: bool,optional
        	default value is Standard_True
        theIsOptimal: bool,optional
        	default value is Standard_False
        theIsShapeToleranceUsed: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _BRepBndLib.brepbndlib_AddOBB(*args)

    @staticmethod
    def AddOptimal(*args) -> "void":
        r"""
        Adds the shape s to the bounding box b. this algorith builds precise bounding box, which differs from exact geometry boundaries of shape only on shape entities tolerances algorithm is the same as for method add(..), but uses more precise methods for building boxes for geometry objects. if useshapetolerance = true, bounding box is enlardged by shape tolerances and these tolerances are used for numerical methods of bounding box size calculations, otherwise bounding box is built according to sizes of uderlined geometrical entities, numerical calculation use tolerance precision::confusion().

        Parameters
        ----------
        S: TopoDS_Shape
        B: Bnd_Box
        useTriangulation: bool,optional
        	default value is Standard_True
        useShapeTolerance: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _BRepBndLib.brepbndlib_AddOptimal(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BRepBndLib.brepbndlib_swiginit(self, _BRepBndLib.new_brepbndlib())
    __swig_destroy__ = _BRepBndLib.delete_brepbndlib

# Register brepbndlib in _BRepBndLib:
_BRepBndLib.brepbndlib_swigregister(brepbndlib)

def brepbndlib_Add(*args) -> "void":
    r"""
    Adds the shape s to the bounding box b. more precisely are successively added to b: - each face of s; the triangulation of the face is used if it exists, - then each edge of s which does not belong to a face, the polygon of the edge is used if it exists - and last each vertex of s which does not belong to an edge. after each elementary operation, the bounding box b is enlarged by the tolerance value of the relative sub-shape. when working with the triangulation of a face this value of enlargement is the sum of the triangulation deflection and the face tolerance. when working with the polygon of an edge this value of enlargement is the sum of the polygon deflection and the edge tolerance. warning - this algorithm is time consuming if triangulation has not been inserted inside the data structure of the shape s. - the resulting bounding box may be somewhat larger than the object.

    Parameters
    ----------
    S: TopoDS_Shape
    B: Bnd_Box
    useTriangulation: bool,optional
    	default value is Standard_True

    Returns
    -------
    None

    """
    return _BRepBndLib.brepbndlib_Add(*args)

def brepbndlib_AddClose(*args) -> "void":
    r"""
    Adds the shape s to the bounding box b. this is a quick algorithm but only works if the shape s is composed of polygonal planar faces, as is the case if s is an approached polyhedral representation of an exact shape. pay particular attention to this because this condition is not checked and, if it not respected, an error may occur in the algorithm for which the bounding box is built. note that the resulting bounding box is not enlarged by the tolerance value of the sub-shapes as is the case with the add function. so the added part of the resulting bounding box is closer to the shape s.

    Parameters
    ----------
    S: TopoDS_Shape
    B: Bnd_Box

    Returns
    -------
    None

    """
    return _BRepBndLib.brepbndlib_AddClose(*args)

def brepbndlib_AddOBB(*args) -> "void":
    r"""
    Computes the oriented bounding box for the shape <thes>. two independent methods of computation are implemented: first method based on set of points (so, it demands the triangulated shape or shape with planar faces and linear edges). the second method is based on use of inertia axes and is called if use of the first method is impossible. if theistriangulationused == false then the triangulation will be ignored at all. if theisshapetoleranceused == true then resulting box will be extended on the tolerance of the shape. theisoptimal flag defines whether to look for the more tight obb for the cost of performance or not.

    Parameters
    ----------
    theS: TopoDS_Shape
    theOBB: Bnd_OBB
    theIsTriangulationUsed: bool,optional
    	default value is Standard_True
    theIsOptimal: bool,optional
    	default value is Standard_False
    theIsShapeToleranceUsed: bool,optional
    	default value is Standard_True

    Returns
    -------
    None

    """
    return _BRepBndLib.brepbndlib_AddOBB(*args)

def brepbndlib_AddOptimal(*args) -> "void":
    r"""
    Adds the shape s to the bounding box b. this algorith builds precise bounding box, which differs from exact geometry boundaries of shape only on shape entities tolerances algorithm is the same as for method add(..), but uses more precise methods for building boxes for geometry objects. if useshapetolerance = true, bounding box is enlardged by shape tolerances and these tolerances are used for numerical methods of bounding box size calculations, otherwise bounding box is built according to sizes of uderlined geometrical entities, numerical calculation use tolerance precision::confusion().

    Parameters
    ----------
    S: TopoDS_Shape
    B: Bnd_Box
    useTriangulation: bool,optional
    	default value is Standard_True
    useShapeTolerance: bool,optional
    	default value is Standard_False

    Returns
    -------
    None

    """
    return _BRepBndLib.brepbndlib_AddOptimal(*args)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BinMNaming module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_binmnaming.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BinMNaming
else:
    import _BinMNaming

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BinMNaming.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BinMNaming.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinMNaming.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinMNaming.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BinMNaming.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BinMNaming.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BinMNaming.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BinMNaming.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BinMNaming.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BinMNaming.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinMNaming.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BinMNaming.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BinMNaming.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinMNaming.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinMNaming.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinMNaming.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BinMNaming.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BinMNaming:
_BinMNaming.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BinMNaming.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BinMDF
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TDF
import OCC.Core.BinObjMgt
import OCC.Core.Storage
import OCC.Core.BinTools
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Geom2d
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_BinMNaming_NamedShapeDriver_Create() -> "opencascade::handle< BinMNaming_NamedShapeDriver >":
    return _BinMNaming.Handle_BinMNaming_NamedShapeDriver_Create()

def Handle_BinMNaming_NamedShapeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMNaming_NamedShapeDriver >":
    return _BinMNaming.Handle_BinMNaming_NamedShapeDriver_DownCast(t)

def Handle_BinMNaming_NamedShapeDriver_IsNull(t: "opencascade::handle< BinMNaming_NamedShapeDriver > const &") -> "bool":
    return _BinMNaming.Handle_BinMNaming_NamedShapeDriver_IsNull(t)

def Handle_BinMNaming_NamingDriver_Create() -> "opencascade::handle< BinMNaming_NamingDriver >":
    return _BinMNaming.Handle_BinMNaming_NamingDriver_Create()

def Handle_BinMNaming_NamingDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMNaming_NamingDriver >":
    return _BinMNaming.Handle_BinMNaming_NamingDriver_DownCast(t)

def Handle_BinMNaming_NamingDriver_IsNull(t: "opencascade::handle< BinMNaming_NamingDriver > const &") -> "bool":
    return _BinMNaming.Handle_BinMNaming_NamingDriver_IsNull(t)
class binmnaming(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <thedrivertable>.

        Parameters
        ----------
        theDriverTable: BinMDF_ADriverTable
        aMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _BinMNaming.binmnaming_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BinMNaming.binmnaming_swiginit(self, _BinMNaming.new_binmnaming())
    __swig_destroy__ = _BinMNaming.delete_binmnaming

# Register binmnaming in _BinMNaming:
_BinMNaming.binmnaming_swigregister(binmnaming)

def binmnaming_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <thedrivertable>.

    Parameters
    ----------
    theDriverTable: BinMDF_ADriverTable
    aMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _BinMNaming.binmnaming_AddDrivers(*args)

class BinMNaming_NamedShapeDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMNaming.BinMNaming_NamedShapeDriver_swiginit(self, _BinMNaming.new_BinMNaming_NamedShapeDriver(*args))

    def Clear(self, *args) -> "void":
        r"""
        Clear myshapeset.

        Returns
        -------
        None

        """
        return _BinMNaming.BinMNaming_NamedShapeDriver_Clear(self, *args)

    def GetFormatNb(self, *args) -> "Standard_Integer":
        r"""
        Get the format of topology.

        Returns
        -------
        int

        """
        return _BinMNaming.BinMNaming_NamedShapeDriver_GetFormatNb(self, *args)

    def GetShapesLocations(self, *args) -> "BinTools_LocationSet &":
        r"""
        Get the format of topology.

        Returns
        -------
        BinTools_LocationSet

        """
        return _BinMNaming.BinMNaming_NamedShapeDriver_GetShapesLocations(self, *args)

    def IsWithTriangles(self, *args) -> "Standard_Boolean":
        r"""
        Return true if shape should be stored with triangles.

        Returns
        -------
        bool

        """
        return _BinMNaming.BinMNaming_NamedShapeDriver_IsWithTriangles(self, *args)

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMNaming.BinMNaming_NamedShapeDriver_Paste(self, *args)

    def ReadShapeSectionFromString(self, src: "std::string") -> "void":
        r"""ReadShapeSectionFromString(BinMNaming_NamedShapeDriver self, std::string src)"""
        return _BinMNaming.BinMNaming_NamedShapeDriver_ReadShapeSectionFromString(self, src)

    def SetFormatNb(self, *args) -> "void":
        r"""
        Set the format of topology first : does not write curveonsurface uv points into the file on reading calls check() method. second: stores curveonsurface uv points.

        Parameters
        ----------
        theFormat: int

        Returns
        -------
        None

        """
        return _BinMNaming.BinMNaming_NamedShapeDriver_SetFormatNb(self, *args)

    def SetWithTriangles(self, *args) -> "void":
        r"""
        Set whether to store triangulation.

        Parameters
        ----------
        isWithTriangles: bool

        Returns
        -------
        None

        """
        return _BinMNaming.BinMNaming_NamedShapeDriver_SetWithTriangles(self, *args)

    def WriteShapeSectionToString(self) -> "std::string":
        r"""WriteShapeSectionToString(BinMNaming_NamedShapeDriver self) -> std::string"""
        return _BinMNaming.BinMNaming_NamedShapeDriver_WriteShapeSectionToString(self)


    @staticmethod
    def DownCast(t):
      return Handle_BinMNaming_NamedShapeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMNaming.delete_BinMNaming_NamedShapeDriver

# Register BinMNaming_NamedShapeDriver in _BinMNaming:
_BinMNaming.BinMNaming_NamedShapeDriver_swigregister(BinMNaming_NamedShapeDriver)

class BinMNaming_NamingDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMNaming.BinMNaming_NamingDriver_swiginit(self, _BinMNaming.new_BinMNaming_NamingDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMNaming.BinMNaming_NamingDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMNaming_NamingDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMNaming.delete_BinMNaming_NamingDriver

# Register BinMNaming_NamingDriver in _BinMNaming:
_BinMNaming.BinMNaming_NamingDriver_swigregister(BinMNaming_NamingDriver)








##Copyright 2016 Thomas Paviot (tpaviot@gmail.com)
##
##This file is part of pythonOCC.
##
##pythonOCC is free software: you can redistribute it and/or modify
##it under the terms of the GNU Lesser General Public License as published by
##the Free Software Foundation, either version 3 of the License, or
##(at your option) any later version.
##
##pythonOCC is distributed in the hope that it will be useful,
##but WITHOUT ANY WARRANTY; without even the implied warranty of
##MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##GNU Lesser General Public License for more details.
##
##You should have received a copy of the GNU Lesser General Public License
##along with pythonOCC.  If not, see <http://www.gnu.org/licenses/>.

""" A very simple webserver. """

import os
import socket
import webbrowser
import errno


def get_available_port(port):
    """ sometimes, the python webserver is closed but the
    port is not made available for a further call. So let's find
    any available port to prevent such issue. This function:
    * takes a port number (an integer), above 1024
    * check if it is available
    * if not, take another one
    * returns the port numer
    """
    if not port > 1024:
        raise AssertionError("port number should be > 1024")
    # check this port is available
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    try:
        s.bind(("127.0.0.1", port))
    except socket.error as e:
        if e.errno == errno.EADDRINUSE:
            print("\nPort %i is already in use. Picking another one." % port)
            # take another one
            s.bind(("", 0))
            port = s.getsockname()[1]
            print("Using port number %i" % port)
        else:
            print("Can't bind to port %i." % port)
    s.close()
    return port


def start_server(addr="127.0.0.1", port=8080, x3d_path='.', open_webbrowser=False):
    """ starts the server if the PYTHONOCC_SHUNT_WEB_SERVER
    env var is not set
    * port: the port number to use (if available) ;
    * path: where thehtml files are located
    * open_webbrower: if True, open the web browser to the correct url
    """
    if os.getenv("PYTHONOCC_SHUNT_WEB_SERVER") == "1":
        return False
    # prefer using Flask, if installed
    try:
        from flask import Flask, send_from_directory
        HAVE_FLASK = True
    except ImportError:
        HAVE_FLASK = False
    if not HAVE_FLASK:  # use simple http server
        from http.server import SimpleHTTPRequestHandler, HTTPServer
        os.chdir(x3d_path)
        port = get_available_port(port)
        httpd = HTTPServer((addr, port), SimpleHTTPRequestHandler)
        print("\n## Serving %s \n## using SimpleHTTPServer" % x3d_path)
        print("## Open your webbrowser at the URL: http://localhost:%i" % port)
        print("## CTRL-C to shutdown the server")
        # open webbrowser
        if open_webbrowser:
            webbrowser.open('http://localhost:%i' % port, new=2)
        # starts the web_server
        httpd.serve_forever()
    else:  # use flask
        # set the project root directory as the static folder, you can set others.
        app = Flask(__name__)

        @app.route('/')
        def root():
            fp = open(os.path.join(x3d_path, 'index.html'))
            html_content = fp.read()
            fp.close()
            return html_content
        @app.route('/<path:path>')
        def send_x3d_content(path):
            return send_from_directory(x3d_path, path)
        print("\n## Serving %s \n## using Flask" % x3d_path)
        print("## Open your webbrowser at the URL: http://localhost:%i" % port)
        print("## CTRL-C to shutdown the server")
        port = get_available_port(port)
        app.run(host=addr, port=port)


if __name__ == "__main__":
    get_available_port(port=8080)
    get_available_port(port=5022)
    start_server(port=8080)
